#ifndef EFL_CANVAS_GESTURE_RECOGNIZER_IMPL_HH
#define EFL_CANVAS_GESTURE_RECOGNIZER_IMPL_HH

#include "efl_canvas_gesture_recognizer.eo.hh"

namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::eina::value_view>::type Gesture_Recognizer::config_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Value * __return_value =  ::efl_gesture_recognizer_config_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::value_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Gesture>::type Gesture_Recognizer::create( ::efl::eolian::in_traits< ::efl::Object>::type target) const
{
    ::Efl_Canvas_Gesture* __return_value =  ::efl_gesture_recognizer_create(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Object*,  ::efl::eolian::in_traits< ::efl::Object>::type>(target));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Gesture>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Canvas_Gesture_Recognizer_Result>::type Gesture_Recognizer::recognize( ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type gesture,  ::efl::eolian::in_traits< ::efl::Object>::type watched,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Touch>::type event) const
{
   Efl_Canvas_Gesture_Recognizer_Result __return_value =  ::efl_gesture_recognizer_recognize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type>(gesture)
      ,  ::efl::eolian::convert_to_c< ::Efl_Object*,  ::efl::eolian::in_traits< ::efl::Object>::type>(watched)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Touch*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Touch>::type>(event));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Canvas_Gesture_Recognizer_Result>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Recognizer::reset( ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type gesture) const
{
    ::efl_gesture_recognizer_reset(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type>(gesture));
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::eina::value_view>::type Gesture_Recognizer::config_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Value * __return_value =  ::efl_gesture_recognizer_config_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::value_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Gesture>::type Gesture_Recognizer::create( ::efl::eolian::in_traits< ::efl::Object>::type target) const
{
    ::Efl_Canvas_Gesture* __return_value =  ::efl_gesture_recognizer_create(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Object*,  ::efl::eolian::in_traits< ::efl::Object>::type>(target));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Gesture>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Canvas_Gesture_Recognizer_Result>::type Gesture_Recognizer::recognize( ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type gesture,  ::efl::eolian::in_traits< ::efl::Object>::type watched,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Touch>::type event) const
{
   Efl_Canvas_Gesture_Recognizer_Result __return_value =  ::efl_gesture_recognizer_recognize(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type>(gesture)
      ,  ::efl::eolian::convert_to_c< ::Efl_Object*,  ::efl::eolian::in_traits< ::efl::Object>::type>(watched)
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Touch*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Touch>::type>(event));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Canvas_Gesture_Recognizer_Result>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Recognizer::reset( ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type gesture) const
{
    ::efl_gesture_recognizer_reset(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture>::type>(gesture));
}
inline efl::canvas::Gesture_Recognizer::operator ::efl::canvas::Gesture_Recognizer() const { return *static_cast< ::efl::canvas::Gesture_Recognizer const*>(static_cast<void const*>(this)); }
inline efl::canvas::Gesture_Recognizer::operator ::efl::canvas::Gesture_Recognizer&() { return *static_cast< ::efl::canvas::Gesture_Recognizer*>(static_cast<void*>(this)); }
inline efl::canvas::Gesture_Recognizer::operator ::efl::canvas::Gesture_Recognizer const&() const { return *static_cast< ::efl::canvas::Gesture_Recognizer const*>(static_cast<void const*>(this)); }
} } }
#endif
